package cn.demo.utils;

import org.apache.http.HttpEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.entity.mime.MultipartEntityBuilder;
import org.apache.http.entity.mime.content.FileBody;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;

import java.io.File;
import java.io.IOException;
import java.util.Map;

/**
 * @ClassName HttpUtils
 * @Description
 */
public class HttpUtil {

    public static String postFile(String apiUrl, File file, Map<String, String> otherParams) throws IOException {
        HttpPost post = new HttpPost(apiUrl);

        MultipartEntityBuilder builder = MultipartEntityBuilder.create();

        if (otherParams != null) {
            for (Map.Entry<String, String> entry : otherParams.entrySet()) {
                builder.addTextBody(entry.getKey(), entry.getValue());
            }
        }

        if (file != null) {
            builder.addPart("file", new FileBody(file));
        }

        HttpEntity entity = builder.build();
        post.setEntity(entity);

        try (CloseableHttpResponse response = HttpClients.createDefault().execute(post)) {
            return EntityUtils.toString(response.getEntity());
        }
    }


    public static String postBase64(String apiUrl, String base64Content) throws IOException {
        HttpPost post = new HttpPost(apiUrl);

        post.setHeader("Content-Type", "application/json");

        StringEntity entity = new StringEntity(base64Content);
        post.setEntity(entity);

        try (CloseableHttpClient httpClient = HttpClients.createDefault();
             CloseableHttpResponse response = httpClient.execute(post)) {

            HttpEntity responseEntity = response.getEntity();
            return EntityUtils.toString(responseEntity);
        }
    }


    public static String postVer(String apiUrl, Map<String, String> otherParams) throws IOException {
        HttpPost post = new HttpPost(apiUrl);

        MultipartEntityBuilder builder = MultipartEntityBuilder.create();

        if (otherParams != null) {
            for (Map.Entry<String, String> entry : otherParams.entrySet()) {
                builder.addTextBody(entry.getKey(), entry.getValue());
            }
        }

        HttpEntity entity = builder.build();
        post.setEntity(entity);

        try (CloseableHttpResponse response = HttpClients.createDefault().execute(post)) {
            return EntityUtils.toString(response.getEntity());
        }
    }
}
